# HMpTy

[![](https://zenodo.org/badge/DOI/10.5281/zenodo.7979507.svg)](https://zenodo.org/doi/10.5281/zenodo.7979507) 



<!-- INFO BADGES -->  

[![](https://img.shields.io/pypi/pyversions/HMpTy)](https://pypi.org/project/HMpTy/)  
[![](https://img.shields.io/pypi/v/HMpTy)](https://pypi.org/project/HMpTy/)  
[![](https://img.shields.io/github/license/thespacedoctor/HMpTy)](https://github.com/thespacedoctor/HMpTy)  
[![](https://img.shields.io/pypi/dm/HMpTy)](https://pypi.org/project/HMpTy/)  

<!-- STATUS BADGES -->  

[![](http://157.245.42.153:8080/buildStatus/icon?job=HMpTy%2Fmaster&subject=build%20master)](http://157.245.42.153:8080/blue/organizations/jenkins/HMpTy/activity?branch=master)  
[![](http://157.245.42.153:8080/buildStatus/icon?job=HMpTy%2Fdevelop&subject=build%20dev)](http://157.245.42.153:8080/blue/organizations/jenkins/HMpTy/activity?branch=develop)  
[![](https://cdn.jsdelivr.net/gh/thespacedoctor/HMpTy@master/coverage.svg)](https://raw.githack.com/thespacedoctor/HMpTy/master/htmlcov/index.html)  
[![](https://readthedocs.org/projects/hmpty/badge/?version=master)](https://HMpTy.readthedocs.io/en/master/)  
[![](https://img.shields.io/github/issues/thespacedoctor/HMpTy/type:%20bug?label=bug%20issues)](https://github.com/thespacedoctor/HMpTy/issues?q=is%3Aissue+is%3Aopen+label%3A%22type%3A+bug%22+)  

*Generate Hierarchical Triangular Mesh (HTM) IDs, crossmatch sets of sky-coordinates and more*.

![](http://i.imgur.com/5GG4979.png)

Documentation for HMpTy is hosted by [Read the Docs](https://HMpTy.readthedocs.io/en/master/) (
[development version](https://HMpTy.readthedocs.io/en/develop/) and [master version](https://HMpTy.readthedocs.io/en/master/)). The code lives on [github](https://github.com/thespacedoctor/HMpTy). Please report any issues you find [here](https://github.com/thespacedoctor/HMpTy/issues).

## Features

* 


## How to cite HMpTy

If you use `HMpTy` in your work, please cite using the following BibTeX entry: 

```bibtex
@software{Young_HMpTy,
  author = {Young, David R.},
  doi = {10.5281/zenodo.7979507},
  license = {GPL-3.0-only},
  title = {{HMpTy. Generate Hierarchical Triangular Mesh (HTM) IDs, crossmatch sets of sky-coordinates and more}},
  url = {https://zenodo.org/doi/10.5281/zenodo.7979507}
}
```
